==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/chp.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	chp.lang.inc.php 2018-02-16
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_CHP_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. zb AT,DE',
	'MODULE_SHIPPING_CHP_ALLOWED_TITLE' => 'Einzelne Versandzonen',
	'MODULE_SHIPPING_CHP_COST_ECO_1_DESC' => 'Tarif Tabelle für die Inlandszone, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_1_TITLE' => 'Tariftabelle für Zone 0 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_2_DESC' => 'Tarif Tabelle für die Zone 1, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_2_TITLE' => 'Tariftabelle für Zone 1 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_3_DESC' => 'Tarif Tabelle für die Zone 2, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_3_TITLE' => 'Tariftabelle für Zone 2 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_4_DESC' => 'Tarif Tabelle für die Zone 3, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_4_TITLE' => 'Tariftabelle für Zone 3 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_5_DESC' => 'Tarif Tabelle für die Zone 4, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_5_TITLE' => 'Tariftabelle für Zone 4 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_6_DESC' => 'Tarif Tabelle für die Zone 5, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_6_TITLE' => 'Tariftabelle für Zone 5 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_7_DESC' => 'Tarif Tabelle für die Zone 6, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_7_TITLE' => 'Tariftabelle für Zone 6 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_PRI_1_DESC' => 'Tarif Tabelle für die Inlandszone, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_1_TITLE' => 'Tariftabelle für Zone 0 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_2_DESC' => 'Tarif Tabelle für die Zone 1, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_2_TITLE' => 'Tariftabelle für Zone 1 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_3_DESC' => 'Tarif Tabelle für die Zone 2, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_3_TITLE' => 'Tariftabelle für Zone 2 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_4_DESC' => 'Tarif Tabelle für die Zone 3, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_4_TITLE' => 'Tariftabelle für Zone 3 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_5_DESC' => 'Tarif Tabelle für die Zone 4, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_5_TITLE' => 'Tariftabelle für Zone 4 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_6_DESC' => 'Tarif Tabelle für die Zone 5, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_6_TITLE' => 'Tariftabelle für Zone 5 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_7_DESC' => 'Tarif Tabelle für die Zone 6, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_7_TITLE' => 'Tariftabelle für Zone 6 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_URG_2_DESC' => 'Tarif Tabelle für die Zone 1, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_2_TITLE' => 'Tariftabelle für Zone 1 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_3_DESC' => 'Tarif Tabelle für die Zone 2, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_3_TITLE' => 'Tariftabelle für Zone 2 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_4_DESC' => 'Tarif Tabelle für die Zone 3, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_4_TITLE' => 'Tariftabelle für Zone 3 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_5_DESC' => 'Tarif Tabelle für die Zone 4, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_5_TITLE' => 'Tariftabelle für Zone 4 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_6_DESC' => 'Tarif Tabelle für die Zone 5, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_6_TITLE' => 'Tariftabelle für Zone 5 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_7_DESC' => 'Tarif Tabelle für die Zone 6, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_7_TITLE' => 'Tariftabelle für Zone 6 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COUNTRIES_1_DESC' => 'Inlandszone',
	'MODULE_SHIPPING_CHP_COUNTRIES_1_TITLE' => 'Tarifzone 0 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_2_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 1 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_2_TITLE' => 'Tarifzone 1 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_3_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 2 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_3_TITLE' => 'Tarifzone 2 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_4_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 3 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_4_TITLE' => 'Tarifzone 3 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_5_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 4 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_5_TITLE' => 'Tarifzone 4 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_6_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 5 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_6_TITLE' => 'Tarifzone 5 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_7_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 6 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_7_TITLE' => 'Tarifzone 6 Länder',
	'MODULE_SHIPPING_CHP_HANDLING_DESC' => 'Bearbeitungsgebühr für diese Versandart in CHF',
	'MODULE_SHIPPING_CHP_HANDLING_TITLE' => 'Handling Fee',
	'MODULE_SHIPPING_CHP_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_CHP_SORT_ORDER_DESC' => 'Niedrigste wird zuerst angezeigt.',
	'MODULE_SHIPPING_CHP_SORT_ORDER_TITLE' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_CHP_STATUS_DESC' => 'Wollen Sie den Versand über die schweizerische Post anbieten?',
	'MODULE_SHIPPING_CHP_STATUS_TITLE' => 'Schweizerische Post',
	'MODULE_SHIPPING_CHP_TAX_CLASS_DESC' => 'Wählen Sie den MwSt.-Satz für diese Versandart aus.',
	'MODULE_SHIPPING_CHP_TAX_CLASS_TITLE' => 'Steuersatz',
	'MODULE_SHIPPING_CHP_TEXT_DESCRIPTION' => 'Die Schweizerische Post',
	'MODULE_SHIPPING_CHP_TEXT_TITLE' => 'Schweizerische Post',
	'MODULE_SHIPPING_CHP_TEXT_UNITS' => 'kg',
	'MODULE_SHIPPING_CHP_TEXT_WAY' => 'Versand nach',
	'MODULE_SHIPPING_CHP_UNDEFINED_RATE' => 'Die Versandkosten können im Moment nicht errechnet werden.',
	'MODULE_SHIPPING_CHP_ZONE_DESC' => 'Wenn Sie eine Zone auswählen, wird diese Versandart nur in dieser Zone angeboten.',
	'MODULE_SHIPPING_CHP_ZONE_TITLE' => 'Versand Zone'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/chp.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	chp.lang.inc.php 2018-02-16
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_CHP_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. zb AT,DE',
	'MODULE_SHIPPING_CHP_ALLOWED_TITLE' => 'Einzelne Versandzonen',
	'MODULE_SHIPPING_CHP_COST_ECO_1_DESC' => 'Tarif Tabelle für die Inlandszone, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_1_TITLE' => 'Tariftabelle für Zone 0 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_2_DESC' => 'Tarif Tabelle für die Zone 1, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_2_TITLE' => 'Tariftabelle für Zone 1 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_3_DESC' => 'Tarif Tabelle für die Zone 2, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_3_TITLE' => 'Tariftabelle für Zone 2 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_4_DESC' => 'Tarif Tabelle für die Zone 3, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_4_TITLE' => 'Tariftabelle für Zone 3 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_5_DESC' => 'Tarif Tabelle für die Zone 4, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_5_TITLE' => 'Tariftabelle für Zone 4 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_6_DESC' => 'Tarif Tabelle für die Zone 5, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_6_TITLE' => 'Tariftabelle für Zone 5 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_ECO_7_DESC' => 'Tarif Tabelle für die Zone 6, basiered auf <b>\'ECO\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_ECO_7_TITLE' => 'Tariftabelle für Zone 6 bis 30 kg ECO',
	'MODULE_SHIPPING_CHP_COST_PRI_1_DESC' => 'Tarif Tabelle für die Inlandszone, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_1_TITLE' => 'Tariftabelle für Zone 0 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_2_DESC' => 'Tarif Tabelle für die Zone 1, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_2_TITLE' => 'Tariftabelle für Zone 1 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_3_DESC' => 'Tarif Tabelle für die Zone 2, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_3_TITLE' => 'Tariftabelle für Zone 2 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_4_DESC' => 'Tarif Tabelle für die Zone 3, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_4_TITLE' => 'Tariftabelle für Zone 3 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_5_DESC' => 'Tarif Tabelle für die Zone 4, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_5_TITLE' => 'Tariftabelle für Zone 4 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_6_DESC' => 'Tarif Tabelle für die Zone 5, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_6_TITLE' => 'Tariftabelle für Zone 5 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_PRI_7_DESC' => 'Tarif Tabelle für die Zone 6, basiered auf <b>\'PRI\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_PRI_7_TITLE' => 'Tariftabelle für Zone 6 bis 30 kg PRI',
	'MODULE_SHIPPING_CHP_COST_URG_2_DESC' => 'Tarif Tabelle für die Zone 1, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_2_TITLE' => 'Tariftabelle für Zone 1 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_3_DESC' => 'Tarif Tabelle für die Zone 2, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_3_TITLE' => 'Tariftabelle für Zone 2 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_4_DESC' => 'Tarif Tabelle für die Zone 3, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_4_TITLE' => 'Tariftabelle für Zone 3 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_5_DESC' => 'Tarif Tabelle für die Zone 4, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_5_TITLE' => 'Tariftabelle für Zone 4 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_6_DESC' => 'Tarif Tabelle für die Zone 5, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_6_TITLE' => 'Tariftabelle für Zone 5 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COST_URG_7_DESC' => 'Tarif Tabelle für die Zone 6, basiered auf <b>\'URG\'</b> bis 30 kg Versandgewicht.',
	'MODULE_SHIPPING_CHP_COST_URG_7_TITLE' => 'Tariftabelle für Zone 6 bis 30 kg URG',
	'MODULE_SHIPPING_CHP_COUNTRIES_1_DESC' => 'Inlandszone',
	'MODULE_SHIPPING_CHP_COUNTRIES_1_TITLE' => 'Tarifzone 0 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_2_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 1 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_2_TITLE' => 'Tarifzone 1 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_3_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 2 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_3_TITLE' => 'Tarifzone 2 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_4_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 3 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_4_TITLE' => 'Tarifzone 3 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_5_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 4 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_5_TITLE' => 'Tarifzone 4 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_6_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 5 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_6_TITLE' => 'Tarifzone 5 Länder',
	'MODULE_SHIPPING_CHP_COUNTRIES_7_DESC' => 'Durch Komma getrennt Liste der Länder als zwei Zeichen ISO-Code Landeskennzahlen, die Teil der Zone 6 sind.',
	'MODULE_SHIPPING_CHP_COUNTRIES_7_TITLE' => 'Tarifzone 6 Länder',
	'MODULE_SHIPPING_CHP_HANDLING_DESC' => 'Bearbeitungsgebühr für diese Versandart in CHF',
	'MODULE_SHIPPING_CHP_HANDLING_TITLE' => 'Handling Fee',
	'MODULE_SHIPPING_CHP_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_CHP_SORT_ORDER_DESC' => 'Niedrigste wird zuerst angezeigt.',
	'MODULE_SHIPPING_CHP_SORT_ORDER_TITLE' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_CHP_STATUS_DESC' => 'Willst du den Versand über die schweizerische Post anbieten?',
	'MODULE_SHIPPING_CHP_STATUS_TITLE' => 'Schweizerische Post',
	'MODULE_SHIPPING_CHP_TAX_CLASS_DESC' => 'Wähle den MwSt.-Satz für diese Versandart aus.',
	'MODULE_SHIPPING_CHP_TAX_CLASS_TITLE' => 'Steuersatz',
	'MODULE_SHIPPING_CHP_TEXT_DESCRIPTION' => 'Die Schweizerische Post',
	'MODULE_SHIPPING_CHP_TEXT_TITLE' => 'Schweizerische Post',
	'MODULE_SHIPPING_CHP_TEXT_UNITS' => 'kg',
	'MODULE_SHIPPING_CHP_TEXT_WAY' => 'Versand nach',
	'MODULE_SHIPPING_CHP_UNDEFINED_RATE' => 'Die Versandkosten können im Moment nicht errechnet werden.',
	'MODULE_SHIPPING_CHP_ZONE_DESC' => 'Wenn du eine Zone auswählst, wird diese Versandart nur in dieser Zone angeboten.',
	'MODULE_SHIPPING_CHP_ZONE_TITLE' => 'Versand Zone'
);
